@@ -12,6 +12,7 @@ import tomlkit
 from tomlkit import parse
 from tomlkit import ws
 from tomlkit._utils import _utc
+from tomlkit.api import document
 from tomlkit.exceptions import NonExistentKey
 
 
@@ -735,6 +736,44 @@ foo = "bar"
     )
 
 
+def test_replace_table_with_value():
+    content = """[foo]
+a = 1
+
+[bar]
+b = 2
+"""
+    doc = parse(content)
+    doc["bar"] = 42
+    assert (
+        doc.as_string()
+        == """bar = 42
+[foo]
+a = 1
+
+"""
+    )
+
+
+def test_replace_preserve_sep():
+    content = """a   =   1
+
+[foo]
+b  =  "what"
+"""
+    doc = parse(content)
+    doc["a"] = 2
+    doc["foo"]["b"] = "how"
+    assert (
+        doc.as_string()
+        == """a   =   2
+
+[foo]
+b  =  "how"
+"""
+    )
+
+
 def test_replace_with_table_of_nested():
     example = """\
     [a]
@@ -889,3 +928,18 @@ def test_pop_add_whitespace_and_insert_table_work_togheter():
     assert out["d"] == 4
     assert "d" not in out["e"]
     assert text == dedent(expected)
+
+
+def test_add_newline_before_super_table():
+    doc = document()
+    doc["a"] = 1
+    doc["b"] = {"c": {}}
+    doc["d"] = {"e": {}}
+    expected = """\
+    a = 1
+
+    [b.c]
+
+    [d.e]
+    """
+    assert doc.as_string() == dedent(expected)
