@@ -17,6 +17,7 @@ from typing import Iterable
 from typing import Iterator
 from typing import List
 from typing import Optional
+from typing import Sequence
 from typing import TypeVar
 from typing import Union
 from typing import cast
@@ -58,6 +59,71 @@ else:
         """Adds MutableMapping mixin while pretending to be a builtin dict"""
 
 
+ItemT = TypeVar("ItemT", bound="Item")
+
+
+@overload
+def item(value: bool) -> "Bool":
+    ...
+
+
+@overload
+def item(value: int) -> "Integer":
+    ...
+
+
+@overload
+def item(value: float) -> "Float":
+    ...
+
+
+@overload
+def item(value: str) -> "String":
+    ...
+
+
+@overload
+def item(value: datetime) -> "DateTime":
+    ...
+
+
+@overload
+def item(value: date) -> "Date":
+    ...
+
+
+@overload
+def item(value: time) -> "Time":
+    ...
+
+
+@overload
+def item(value: Sequence[dict]) -> "AoT":
+    ...
+
+
+@overload
+def item(value: Sequence) -> "Array":
+    ...
+
+
+@overload
+def item(value: dict, _parent: "Array" = ..., _sort_keys: bool = ...) -> "InlineTable":
+    ...
+
+
+@overload
+def item(
+    value: dict, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
+) -> "Table":
+    ...
+
+
+@overload
+def item(value: ItemT) -> ItemT:
+    ...
+
+
 def item(
     value: Any, _parent: Optional["Item"] = None, _sort_keys: bool = False
 ) -> "Item":
@@ -721,8 +787,7 @@ class DateTime(Item, datetime):
         second: int,
         microsecond: int,
         tzinfo: Optional[tzinfo],
-        trivia: Trivia,
-        raw: str,
+        *_: Any,
         **kwargs: Any,
     ) -> datetime:
         return datetime.__new__(
@@ -748,12 +813,13 @@ class DateTime(Item, datetime):
         second: int,
         microsecond: int,
         tzinfo: Optional[tzinfo],
-        trivia: Trivia,
-        raw: str,
+        trivia: Optional[Trivia] = None,
+        raw: Optional[str] = None,
+        **kwargs: Any,
     ) -> None:
-        super().__init__(trivia)
+        super().__init__(trivia or Trivia())
 
-        self._raw = raw
+        self._raw = raw or self.isoformat()
 
     @property
     def discriminant(self) -> int:
@@ -803,7 +869,16 @@ class DateTime(Item, datetime):
 
         return result
 
-    def _new(self, result):
+    def replace(self, *args: Any, **kwargs: Any) -> datetime:
+        return self._new(super().replace(*args, **kwargs))
+
+    def astimezone(self, tz: tzinfo) -> datetime:
+        result = super().astimezone(tz)
+        if PY38:
+            return result
+        return self._new(result)
+
+    def _new(self, result) -> "DateTime":
         raw = result.isoformat()
 
         return DateTime(
@@ -879,6 +954,9 @@ class Date(Item, date):
 
         return result
 
+    def replace(self, *args: Any, **kwargs: Any) -> date:
+        return self._new(super().replace(*args, **kwargs))
+
     def _new(self, result):
         raw = result.isoformat()
 
@@ -929,6 +1007,22 @@ class Time(Item, time):
     def as_string(self) -> str:
         return self._raw
 
+    def replace(self, *args: Any, **kwargs: Any) -> time:
+        return self._new(super().replace(*args, **kwargs))
+
+    def _new(self, result):
+        raw = result.isoformat()
+
+        return Time(
+            result.hour,
+            result.minute,
+            result.second,
+            result.microsecond,
+            result.tzinfo,
+            self._trivia,
+            raw,
+        )
+
     def _getstate(self, protocol: int = 3) -> tuple:
         return (
             self.hour,
@@ -997,7 +1091,7 @@ class Array(Item, _CustomList):
             for v in self._value
             if not isinstance(v, Whitespace)
         )
-        s += "]"
+        s += self.trivia.indent + "]"
 
         return s
 
